# "fix" underlinking:
%define _disable_ld_no_undefined 1

Name:           coq
Version:        8.11.0
Release:        %mkrel 4
Summary:        The Coq Proof Assistant
Group:          Sciences/Computer science
License:        LGPLv2
URL:            https://coq.inria.fr
Source0:        https://github.com/coq/coq/archive/V%{version}/%{name}-%{version}.tar.gz
Source1:        https://coq.inria.fr/distrib/V%{version}/files/Tutorial.pdf
Source2:        https://coq.inria.fr/distrib/V%{version}/files/Reference-Manual.pdf
Source3:        https://coq.inria.fr/distrib/V%{version}/files/RecTutorial.pdf
Patch0:		Use-the-Alloc_small-macro-from-the-OCaml-runtime.patch
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-camlp5-devel
BuildRequires:  ocaml-cairo-devel
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-lablgtk3-devel
BuildRequires:  ocaml-lablgtk3-sourceview3-devel
BuildRequires:  ocaml-num-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  texlive
BuildRequires:  imagemagick
BuildRequires:  gtksourceview3-devel
BuildRequires:  libicns-utils
BuildRequires:  python3-devel
BuildRequires:  time

# Exclude 3 private ocaml interfaces that we don't Provide, and a Provides that
# the automatic generator is failing to produce for ocaml-lablgtk
%global __requires_exclude ocamlx?\\\((Configwin_types|Interface|Richpp|GtkSourceView2_types|Xml_parser|Xml_printer|Xmlprotocol|Serialize)\\\)

%description
Coq is a proof assistant which:
  - allows to handle calculus assertions,
  - check mechanically proofs of these assertions,
  - helps to find formal proofs,
  - extracts a certified program from the constructive proof
    of its formal specification.


%package ide
Summary:        The Coq Integrated Development Interface
Group:          Sciences/Computer science
Requires:       %{name} = %{version}

%description ide
The Coq Integrated Development Interface is a graphical interface for the
Coq proof assistant.


%package doc
Summary:        Documentation for %{name}
Group:          Documentation
License:        Open Publication License
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation for %{name}.

%prep
%setup -q
%autopatch -p1

cp %{SOURCE1} \
   %{SOURCE2} \
   %{SOURCE3} .

# Use relro due to network use.  Also fix broken CAML_LD_LIBRARY_PATH.
sed -e 's/-lunix/& -ccopt -Wl,-z,relro/' \
    -e "s,'%s/kernel/byterun',%s/kernel/byterun," \
    -i configure.ml

# Use our CFLAGS
sed -i 's|-Wall.*-O2|%{optflags} -Wno-unused|' configure.ml

# Make sure debuginfo is generated
sed -i 's,-shared,& -g,g' tools/CoqMakefile.in Makefile.build

# Do not invoke env
for f in $(grep -Frl '/usr/bin/env bash'); do
  sed -i 's,/usr/bin/env bash,/bin/bash,' $f
done
sed -i 's,/usr/bin/env python,/usr/bin/python3,' tools/*.py
sed -i 's,/usr/bin/env python3,/usr/bin/python3,' \
    dev/tools/github-check-prs.py doc/sphinx/conf.py \
    doc/tools/coqrst/regen_readme.py
sed -i 's,/usr/bin/env python2,/usr/bin/python2,' \
    doc/tools/coqrst/notations/fontsupport.py
sed -i 's,/usr/bin/env time,/usr/bin/time,' tools/CoqMakefile.in Makefile.build

# Work around pr_dump.cmo snafu with recent versions of ocaml-camlp5
sed -i 's/ -I \$(MYCAMLP5LIB) \$(PR_O)//' Makefile.build Makefile.ide

%build
%ifarch %{ocaml_native_compiler}
%global opt_option -native-compiler yes -natdynlink yes -coqide opt
%else
%global opt_option -bytecode-compiler yes -byte-only -coqide byte
%endif
 
./configure \
        -mandir %{_mandir} \
        -bindir %{_bindir} \
        -libdir %{_libdir}/coq \
        -coqdocdir %{_datadir}/texmf/tex/latex/misc \
        -configdir %{_sysconfdir}/xdg/coq \
        -docdir %{_datadir}/doc/%{name} \
        -datadir %{_datadir}/%{name} \
        -browser "xdg-open %s" \
        %{opt_option}          \

export LD_LIBRARY_PATH=%{_libdir}/ocaml/stublibs

export CAML_LD_LIBRARY_PATH=$PWD/kernel/byterun:${CAML_LD_LIBRARY_PATH}
make world


%install
make COQINSTALLPREFIX=%{buildroot} install-coq
make COQINSTALLPREFIX=%{buildroot} install-coqide
export EXCLUDE_FROM_STRIP=%{_bindir}

for png in 256x256 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png ide/%{name}.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=CoqIDE
Comment=Coq integrated developpment environment
Exec=%{_bindir}/coqide
Icon=coq
Type=Application
Categories=Education;Science;Math;
EOF


%files
%doc README.md CREDITS
%license LICENSE
%doc %{_docdir}/%{name}/FAQ-CoqIde
%{_bindir}/*
%{_libdir}/coq
%{_mandir}/man1/*
%{_datadir}/texmf/tex/latex/misc/*
%{_datadir}/%{name}/
%exclude %{_bindir}/coqide*
%exclude %{_libdir}/coq/ide

%files ide
%doc ide/FAQ
%{_sysconfdir}/xdg/coq/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_bindir}/coqide*
%{_libdir}/coq/ide

%files doc
%doc Tutorial.pdf
%doc Reference-Manual.pdf
%doc RecTutorial.pdf


%changelog
* Mon Jan 11 2021 pterjan <pterjan> 8.11.0-4.mga8
+ Revision: 1671200
- Exclude more private modules
- Also exclude ocamlx requires when we exclude ocaml ones

* Sun Jan 10 2021 pterjan <pterjan> 8.11.0-2.mga8
+ Revision: 1670853
- Rebuild to generate ocamlx provides
+ tv <tv>
- remove one BR workaround which is now fixed

* Sun Mar 01 2020 tv <tv> 8.11.0-1.mga8
+ Revision: 1552552
- BR ocaml-cairo-devel (probably a missing dep of other BRs)
- BR ocaml-lablgtk3-sourceview3
+ pterjan <pterjan>
- Update to 8.11.0
+ umeabot <umeabot>
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 8.9.1-3.mga8
+ Revision: 1545296
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 tv <tv> 8.9.1-2.mga8
+ Revision: 1484376
- filter out a bogus requires on private ocaml interface
- consolidate exclude list

* Sun Jan 26 2020 tv <tv> 8.9.1-1.mga8
+ Revision: 1483034
- revert back to 8.9.1 & fix build
- new release + rebuild for ocaml-4.10
- new release + rebuild for ocaml-4.10
+ pterjan <pterjan>
- Rebuild for ocaml 4.07.1

* Wed Oct 24 2018 tv <tv> 8.7.1-1.mga7
+ Revision: 1325023
- new release
- rebuild with ocaml-4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 8.6.1-3.mga7
+ Revision: 1296798
- Mageia 7 Mass Rebuild

* Mon Dec 04 2017 tv <tv> 8.6.1-2.mga7
+ Revision: 1181263
- fix deps

* Mon Dec 04 2017 tv <tv> 8.6.1-1.mga7
+ Revision: 1181238
- new release
- add fixes from FC
- rebuild for new ocaml
+ shlomif <shlomif>
- New version 8.6 (requires new deps).

* Sun Sep 25 2016 pterjan <pterjan> 8.5pl2-2.mga6
+ Revision: 1056205
- Rebuild for fix in ocaml

* Sun Sep 18 2016 daviddavid <daviddavid> 8.5pl2-1.mga6
+ Revision: 1053630
- new version: 8.5pl2
- update URL and Sources URL
- exclude a private ocaml interface that we don't Provide, and a Provides that
  the automatic generator is failing to produce for ocaml-lablgtk
- add RecTutorial.pdf as a doc file
- update doc files and files list

* Tue Feb 02 2016 pterjan <pterjan> 8.4pl6-1.mga6
+ Revision: 930946
- Update to 8.4pl6

* Fri Sep 11 2015 neoclust <neoclust> 8.4pl4-7.mga6
+ Revision: 876969
- Enable debug

* Fri Sep 11 2015 neoclust <neoclust> 8.4pl4-6.mga6
+ Revision: 876939
- Fix build with new rpm ( empty debuginfo)

* Wed Oct 15 2014 umeabot <umeabot> 8.4pl4-5.mga5
+ Revision: 740302
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 8.4pl4-4.mga5
+ Revision: 725007
- rebuild for bogus file deps

* Thu Sep 18 2014 umeabot <umeabot> 8.4pl4-3.mga5
+ Revision: 693686
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 8.4pl4-2.mga5
+ Revision: 678542
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 malo <malo> 8.4pl4-1.mga5
+ Revision: 638780
- update to 8.4pl4

* Sat Oct 19 2013 umeabot <umeabot> 8.4pl2-3.mga4
+ Revision: 527415
- Mageia 4 Mass Rebuild
+ luigiwalser <luigiwalser>
- fix check for make version

* Fri Jun 07 2013 malo <malo> 8.4pl2-1.mga4
+ Revision: 440012
- update to 8.4pl2 (patch from William Murphy)

* Mon Jan 14 2013 malo <malo> 8.4pl1-1.mga3
+ Revision: 387353
- new bugfix release 8.4pl1
- remove patch which was included upstream

* Fri Jan 11 2013 umeabot <umeabot> 8.4-3.mga3
+ Revision: 348157
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 blue_prawn <blue_prawn> 8.4-2.mga3
+ Revision: 302076
- build requires ocaml-compiler-libs
- rebuild with new ocaml 4.00
- also include documentation

* Sun Aug 26 2012 malo <malo> 8.4-1.mga3
+ Revision: 284166
- missing buildrequires on camlp4-devel
- update to version 8.4
- add patch from Gentoo for compatibility with lablgtk 2.16
- add desktop file for the IDE

* Sun Jul 29 2012 malo <malo> 8.3pl4-1.mga3
+ Revision: 275566
- new version 8.3pl4
- fix requires to ocaml-compiler

* Sat Jan 14 2012 malo <malo> 8.3pl3-1.mga2
+ Revision: 195965
- new version 8.3pl3

* Sun Oct 23 2011 malo <malo> 8.3pl2-1.mga2
+ Revision: 157538
- imported package coq

